#
#  YKLook... GUI Library, border-factory (for Ruby)
#
#  Copyright (c) 2009-2010 YorozuKotowariYa Ltd.
#
class YKLookBorderBase < YKLookSwingBase
end
class YKLookBorder < YKLookBorderBase
	def initialize( prm_ary = nil )
		super()
		if prm_ary.nil?()
			prm_ary = [ 'ETC' ]
		end
		if not prm_ary.kind_of?(Array)
			raise YKLookErrorSwing, 'notArray'
		end
		case prm_ary[0][0,3].upcase()
			when 'SOF' then yks_bevel(  prm_ary, 'yk_createSoftBevelBorder' )
			when 'BEV' then yks_bevel(  prm_ary, 'yk_createBevelBorder' )
			when 'EMP' then yks_empty(  prm_ary )
			when 'ETC' then yks_etched( prm_ary )
			when 'LIN' then yks_line(   prm_ary )
			when 'MAT' then yks_matte(  prm_ary )
			when 'GRO' then yks_groove( prm_ary )
			when 'RID' then yks_ridge(  prm_ary )
			when 'INS' then yks_inset(  prm_ary, 'yk_createBevelBorder' )
			when 'OUT' then yks_outset( prm_ary, 'yk_createBevelBorder' )
			when 'SOL' then yks_line(   prm_ary )
			else raise YKLookErrorSwing, 'illBorderStyle'
		end
	end
	def yks_bevel( prm_ary, prm_met )
		case prm_ary[1][0,1].upcase()
			when 'L', 'R'
			else raise YKLookErrorSwing, 'illBevelType'
		end
		ary = [ prm_ary[1] ]
		if prm_ary.size() >= 4
			ary << yks_encode_color( prm_ary[2] )
			ary << yks_encode_color( prm_ary[3] )
		end
		if prm_ary.size() >= 6
			ary << yks_encode_color( prm_ary[4] )
			ary << yks_encode_color( prm_ary[5] )
		end
		yks_rpca( prm_met, ary )
	end
	def yks_empty( prm_ary )
		if prm_ary.size() < 5
			raise YKLookErrorSwing, 'illArraySize'
		end
		yks_rpca( 'yk_createEmptyBorder', prm_ary[1..4] )
	end
	def yks_etched( prm_ary )
		ary = []
		if prm_ary.size() >= 2
			case prm_ary[1][0,1].upcase()
				when 'L', 'R', 'G'
				else raise YKLookErrorSwing, 'illBevelType'
			end
			ary << [ prm_ary[1] ]
		end
		if prm_ary.size() >= 4
			ary << yks_encode_color( prm_ary[2] )
			ary << yks_encode_color( prm_ary[3] )
		end
		yks_rpca( 'yk_createEtchedBorder', ary )
	end
	def yks_line( prm_ary )
		ary = [ yks_encode_color( prm_ary[1] ) ]
		if prm_ary.size() >= 3
			ary << prm_ary[2]
		end
		yks_rpca( 'yk_createLineBorder', ary )
	end
	def yks_matte( prm_ary )
		if prm_ary.size() < 6
			raise YKLookErrorSwing, 'illArraySize'
		end
		if prm_ary[5].kind_of?(YKLookImage)
			typ = 'i'
			obj = prm_ary[5].yk_id()
		else
			typ = 'c'
			obj = yks_encode_color( prm_ary[5] )
		end
		yks_rpc( 'yk_createMatteBorder', prm_ary[1], prm_ary[2],
										prm_ary[3], prm_ary[4], typ, obj )
	end
	def yks_groove( prm_ary )
		ary = prm_ary.dup()
		ary.insert( 1, 'L' )
		yks_etched( ary )
	end
	def yks_ridge( prm_ary )
		ary = prm_ary.dup()
		ary.insert( 1, 'R' )
		yks_etched( ary )
	end
	def yks_inset( prm_ary, prm_met )
		ary = prm_ary.dup()
		ary.insert( 1, 'L' )
		yks_bevel( prm_ary, prm_met )
	end
	def yks_outset( prm_ary, prm_met )
		ary = prm_ary.dup()
		ary.insert( 1, 'R' )
		yks_bevel( prm_ary, prm_met )
	end
end
class YKLookBorderTitled < YKLookBorderBase
	def initialize( prm_bdr, prm_ttl )
		super()
		if not prm_bdr.kind_of?(YKLookBorder)
			prm_bdr = YKLookBorder.new( prm_bdr )
		end
		if not prm_bdr.kind_of?(YKLookBorder)
			raise YKLookErrorSwing, 'notBorder'
		end
		ary = [ prm_bdr.yk_id() ]
		if prm_ttl.kind_of?(String)
			ary << YKLookMain.yks_encode_string( prm_ttl )
		else
			ary << YKLookMain.yks_encode_string( prm_ttl[0] )
			if prm_ttl.size() >= 2
				case prm_ttl[1][0,3].upcase()
					when 'LEF','CEN','RIG','LEA','TRA','DEF'
					else raise YKLookErrorSwing, 'illJustification'
				end
				ary << prm_ttl[1]
			end
			if prm_ttl.size() >= 3
				pos = [ 'ABOVE_TOP', 'TOP', 'BELOW_TOP', 'ABOVE_BOTTOM',
						'BOTTOM', 'BELOW_BOTTOM', 'DEFAULT' ]
				if not pos.include?( prm_ttl[2].upcase() )
					raise YKLookErrorSwing, 'illPosition'
				end
				ary << prm_ttl[2]
			end
			if prm_ttl.size() >= 4
				if prm_ttl[3].kind_of?(YKLookFont)
					ary << prm_ttl[3].yk_id()
				else
					if not prm_ttl[3].nil?()
						raise YKLookErrorSwing, 'notFont'
					end
					ary << 'null'
				end
			end
			if prm_ttl.size() >= 5
				ary << yks_encode_color( prm_ttl[4] )
			end
		end
		yks_rpca( 'yk_createTitledBorder', ary )
	end
end
class YKLookBorderCompound < YKLookBorderBase
	def initialize( prm_outer, prm_inner )
		super()
		if not prm_outer.kind_of?(YKLookBorderBase) or
			not prm_inner.kind_of?(YKLookBorderBase)
			raise YKLookErrorSwing, 'notBorder'
		end
		yks_rpc('yk_createCompoundBorder', prm_outer.yk_id(), prm_inner.yk_id())
	end
end

# end
